Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
arrakis/__init__.py | (no function) | 15 | 3 | 0 | 80.0%
arrakis/__main__.py | add_subparser | 3 | 0 | 0 | 100.0%
arrakis/__main__.py | parse_pattern | 3 | 3 | 0 | 0.0%
arrakis/__main__.py | print_channel | 2 | 0 | 0 | 100.0%
arrakis/__main__.py | _add_find_count_args | 5 | 0 | 0 | 100.0%
arrakis/__main__.py | find | 6 | 0 | 0 | 100.0%
arrakis/__main__.py | count | 3 | 0 | 0 | 100.0%
arrakis/__main__.py | describe | 6 | 0 | 0 | 100.0%
arrakis/__main__.py | stream | 13 | 2 | 0 | 84.6%
arrakis/__main__.py | fetch | 6 | 6 | 0 | 0.0%
arrakis/__main__.py | publish | 29 | 29 | 0 | 0.0%
arrakis/__main__.py | publish._gen_data | 15 | 15 | 0 | 0.0%
arrakis/__main__.py | main | 16 | 5 | 0 | 68.8%
arrakis/__main__.py | (no function) | 51 | 3 | 0 | 94.1%
arrakis/api.py | find | 1 | 0 | 0 | 100.0%
arrakis/api.py | count | 1 | 0 | 0 | 100.0%
arrakis/api.py | describe | 1 | 0 | 0 | 100.0%
arrakis/api.py | stream | 1 | 1 | 0 | 0.0%
arrakis/api.py | fetch | 1 | 0 | 0 | 100.0%
arrakis/api.py | (no function) | 10 | 0 | 0 | 100.0%
arrakis/block.py | Freq.__rmul__ | 1 | 0 | 0 | 100.0%
arrakis/block.py | time_as_ns | 3 | 0 | 0 | 100.0%
arrakis/block.py | Series.time | 1 | 1 | 0 | 0.0%
arrakis/block.py | Series.t0 | 1 | 1 | 0 | 0.0%
arrakis/block.py | Series.duration | 1 | 1 | 0 | 0.0%
arrakis/block.py | Series.duration_ns | 1 | 0 | 0 | 100.0%
arrakis/block.py | Series.dt | 1 | 1 | 0 | 0.0%
arrakis/block.py | Series.name | 1 | 0 | 0 | 100.0%
arrakis/block.py | Series.data_type | 1 | 0 | 0 | 100.0%
arrakis/block.py | Series.dtype | 1 | 1 | 0 | 0.0%
arrakis/block.py | Series.sample_rate | 1 | 0 | 0 | 100.0%
arrakis/block.py | Series.times | 1 | 1 | 0 | 0.0%
arrakis/block.py | Series.has_nulls | 1 | 1 | 0 | 0.0%
arrakis/block.py | Series.__len__ | 1 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.__post_init__ | 6 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.time | 1 | 1 | 0 | 0.0%
arrakis/block.py | SeriesBlock.t0 | 1 | 1 | 0 | 0.0%
arrakis/block.py | SeriesBlock.duration | 1 | 1 | 0 | 0.0%
arrakis/block.py | SeriesBlock.duration_ns | 1 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.__getitem__ | 1 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.__len__ | 1 | 1 | 0 | 0.0%
arrakis/block.py | SeriesBlock.keys | 1 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.items | 2 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.values | 1 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.filter | 7 | 7 | 0 | 0.0%
arrakis/block.py | SeriesBlock.create_gaps | 9 | 9 | 0 | 0.0%
arrakis/block.py | SeriesBlock.to_column_batch | 4 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.to_row_batches | 10 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.from_column_batch | 6 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock.from_row_batch | 9 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock._generate_column_schema | 5 | 0 | 0 | 100.0%
arrakis/block.py | SeriesBlock._generate_row_schema | 1 | 0 | 0 | 100.0%
arrakis/block.py | concatenate_blocks | 13 | 0 | 0 | 100.0%
arrakis/block.py | combine_blocks | 12 | 0 | 0 | 100.0%
arrakis/block.py | _numpy_to_arrow_list_array | 6 | 0 | 0 | 100.0%
arrakis/block.py | _arrow_to_numpy_array | 15 | 1 | 0 | 93.3%
arrakis/block.py | _arrow_to_numpy_dtype | 6 | 1 | 0 | 83.3%
arrakis/block.py | (no function) | 91 | 0 | 3 | 100.0%
arrakis/channel.py | Channel.dtype | 1 | 0 | 0 | 100.0%
arrakis/channel.py | Channel.__post_init__ | 2 | 0 | 0 | 100.0%
arrakis/channel.py | Channel.validate | 4 | 0 | 0 | 100.0%
arrakis/channel.py | Channel.__repr__ | 1 | 0 | 0 | 100.0%
arrakis/channel.py | Channel.__str__ | 1 | 0 | 0 | 100.0%
arrakis/channel.py | Channel.__eq__ | 8 | 1 | 0 | 87.5%
arrakis/channel.py | Channel.domain | 1 | 0 | 0 | 100.0%
arrakis/channel.py | Channel.to_json | 6 | 1 | 0 | 83.3%
arrakis/channel.py | Channel.from_json | 3 | 0 | 0 | 100.0%
arrakis/channel.py | Channel.from_field | 3 | 0 | 0 | 100.0%
arrakis/channel.py | _list_dtype_to_str | 6 | 2 | 0 | 66.7%
arrakis/channel.py | (no function) | 30 | 0 | 2 | 100.0%
arrakis/client.py | get_flight_info | 3 | 0 | 0 | 100.0%
arrakis/client.py | Client.__init__ | 3 | 0 | 0 | 100.0%
arrakis/client.py | Client.find | 12 | 2 | 0 | 83.3%
arrakis/client.py | Client.count | 17 | 2 | 0 | 88.2%
arrakis/client.py | Client.describe | 3 | 0 | 0 | 100.0%
arrakis/client.py | Client.stream | 23 | 0 | 0 | 100.0%
arrakis/client.py | Client.fetch | 1 | 0 | 0 | 100.0%
arrakis/client.py | Client._stream_channel_metadata | 4 | 0 | 0 | 100.0%
arrakis/client.py | _parse_data_types | 5 | 0 | 0 | 100.0%
arrakis/client.py | (no function) | 23 | 0 | 0 | 100.0%
arrakis/constants.py | (no function) | 8 | 0 | 0 | 100.0%
arrakis/flight.py | RequestValidator.__init__ | 5 | 0 | 0 | 100.0%
arrakis/flight.py | RequestValidator.validate | 8 | 0 | 0 | 100.0%
arrakis/flight.py | parse_url | 8 | 2 | 0 | 75.0%
arrakis/flight.py | create_command | 3 | 0 | 0 | 100.0%
arrakis/flight.py | create_descriptor | 2 | 0 | 0 | 100.0%
arrakis/flight.py | parse_command | 7 | 0 | 0 | 100.0%
arrakis/flight.py | MultiEndpointStream.__init__ | 7 | 0 | 0 | 100.0%
arrakis/flight.py | MultiEndpointStream._execute_endpoint | 13 | 2 | 0 | 84.6%
arrakis/flight.py | MultiEndpointStream.__iter__ | 12 | 1 | 0 | 91.7%
arrakis/flight.py | MultiEndpointStream.unpack | 2 | 0 | 0 | 100.0%
arrakis/flight.py | MultiEndpointStream.close | 10 | 3 | 0 | 70.0%
arrakis/flight.py | MultiEndpointStream.__exit__ | 1 | 0 | 0 | 100.0%
arrakis/flight.py | (no function) | 45 | 0 | 3 | 100.0%
arrakis/mux.py | MuxedData.__getitem__ | 1 | 0 | 0 | 100.0%
arrakis/mux.py | MuxedData.__iter__ | 1 | 0 | 0 | 100.0%
arrakis/mux.py | MuxedData.__len__ | 1 | 1 | 0 | 0.0%
arrakis/mux.py | Muxer.__init__ | 7 | 0 | 0 | 100.0%
arrakis/mux.py | Muxer.push | 21 | 14 | 0 | 33.3%
arrakis/mux.py | Muxer.pull | 9 | 1 | 0 | 88.9%
arrakis/mux.py | Muxer._has_all_items | 1 | 0 | 0 | 100.0%
arrakis/mux.py | Muxer._are_items_stale | 7 | 7 | 0 | 0.0%
arrakis/mux.py | (no function) | 32 | 0 | 0 | 100.0%
arrakis/publish.py | serialize_batch | 4 | 0 | 0 | 100.0%
arrakis/publish.py | channel_to_dtype_name | 4 | 4 | 0 | 0.0%
arrakis/publish.py | Publisher.__init__ | 10 | 2 | 0 | 80.0%
arrakis/publish.py | Publisher.register | 13 | 0 | 0 | 100.0%
arrakis/publish.py | Publisher.enter | 12 | 2 | 0 | 83.3%
arrakis/publish.py | Publisher.__enter__ | 2 | 0 | 0 | 100.0%
arrakis/publish.py | Publisher.publish | 12 | 0 | 0 | 100.0%
arrakis/publish.py | Publisher._update_partitions | 0 | 0 | 48 | 100.0%
arrakis/publish.py | Publisher.close | 3 | 0 | 0 | 100.0%
arrakis/publish.py | Publisher.__exit__ | 2 | 0 | 0 | 100.0%
arrakis/publish.py | (no function) | 25 | 2 | 9 | 92.0%
Total |  | 872 | 145 | 65 | 83.4%

No items found using the specified filter.